% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/main_default_ORFikExp.R
\name{multiOmicsPlot_ORFikExp}
\alias{multiOmicsPlot_ORFikExp}
\title{Multi-omics plot using ORFik experiment input}
\usage{
multiOmicsPlot_ORFikExp(
  target_range,
  annotation = target_range,
  df,
  reference_sequence = findFa(df),
  reads = outputLibs(df, type = "pshifted", output.mode = "envirlist", naming = "full"),
  withFrames = libraryTypes(df, uniqueTypes = FALSE) \%in\% c("RFP", "RPF", "LSU"),
  frames_type = "lines",
  colors = NULL,
  kmers = NULL,
  kmers_type = c("mean", "sum")[1],
  ylabels = bamVarName(df),
  proportions = NULL,
  width = NULL,
  height = NULL,
  plot_name = "default",
  plot_title = NULL,
  display_sequence = FALSE,
  annotation_names = NULL,
  start_codons = "ATG",
  stop_codons = c("TAA", "TAG", "TGA"),
  custom_motif = NULL,
  BPPARAM = bpparam()
)
}
\arguments{
\item{target_range}{the whole region to visualize,
a \code{\link[GenomicRanges]{GRangesList}} or \code{\link[GenomicRanges]{GRanges}} object}

\item{annotation}{the whole annotation which your target region is a subset,
a \code{\link[GenomicRanges]{GRangesList}} or \code{\link[GenomicRanges]{GRanges}} object}

\item{df}{an ORFik \code{\link[ORFik]{experiment}} or a list containing ORFik experiments.
Usually a list when you have split Ribo-seq and RNA-seq etc.}

\item{reference_sequence}{the genome reference, default ORFik::findFa(df)}

\item{reads}{the NGS libraries, as a list of \code{\link[GenomicRanges]{GRanges}} with or without score column for replicates.
Default: \code{outputLibs(df, type = "pshifted", output.mode = "envirlist", naming = "full")}}

\item{withFrames}{a logical vector, default
\code{libraryTypes(df, uniqueTypes = FALSE) \%in\% c("RFP", "RPF", "LSU")}
Alternative: a length 1 or same length as list length of "reads" argument.}

\item{frames_type}{character, default "lines". Alternative:\cr
- columns \cr
- stacks \cr
- area}

\item{colors}{character, default NULL (automatic colouring). If "withFrames" argument
is TRUE, colors are set to to c("red", "green", "blue") for the 3 frames.
Alternative:  Character vector of length 1 or length of "reads" list argument.}

\item{kmers}{numeric (integer), bin positions into kmers.}

\item{kmers_type}{character, function used for kmers sliding window. default: "mean", alternative: "sum"}

\item{ylabels}{character, default \code{bamVarName(df)}. Name of libraries in "reads" list argument.}

\item{proportions}{numeric, default NULL. Width of plot.}

\item{width}{numeric, default NULL. Width of plot.}

\item{height}{numeric, default NULL. Height of plot.}

\item{plot_name}{character, default "default" (will create name from target_range name).
Alternative: custom name for region.}

\item{plot_title}{character, default NULL. A title for plot.}

\item{display_sequence}{logical, default FALSE. If TRUE, display nucleotide sequence in plot.}

\item{annotation_names}{character, default NULL. Alternative naming for annotation.}

\item{start_codons}{character vector, default "ATG"}

\item{stop_codons}{character vector, default c("TAA", "TAG", "TGA")}

\item{custom_motif}{character vector, default NULL.}

\item{BPPARAM}{how many cores/threads to use? default: \code{BiocParallel::bpparam()}.
To see number of threads used, do \code{BiocParallel::bpparam()$workers}.
You can also add a time remaining bar, for a more detailed pipeline.}
}
\value{
the plot object
}
\description{
Customizable html plots for visualizing genomic data.
}
\examples{
library(ORFik)
df <- ORFik.template.experiment()[3,] #Use third library in experiment only
if (requireNamespace("BSgenome.Hsapiens.UCSC.hg19")) {
  cds <- loadRegion(df, "cds")
  multiOmicsPlot_ORFikExp(extendLeaders(extendTrailers(cds[1], 30), 30), df = df,
                        reference_sequence = BSgenome.Hsapiens.UCSC.hg19::Hsapiens,
                        frames_type = "columns")
}
}
